OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Não é possível gravar na pasta \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Isto normalmente pode ser resolvido, dando ao servidor da Web direitos de gravação para a diretoria de configuração",
    "See %s" : "Ver %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Isto normalmente pode ser resolvido, %sdando ao servidor da Web acesso de gravação para a diretoria de configuração %s.",
    "Sample configuration detected" : "Detetado exemplo de configuração",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração de amostra foi copiada. Isso pode danificar a sua instalação e não é suportado. Por favor, leia a documentação antes de realizar mudanças no ficheiro config.php",
    "PHP %s or higher is required." : "Necessário PHP %s ou superior.",
    "PHP with a version lower than %s is required." : "É necessário um PHP com uma versão inferir a %s.",
    "%sbit or higher PHP required." : "Necessário PHP %sbit ou superior.",
    "Following databases are supported: %s" : "São suportadas as seguintes bases de dados: %s",
    "The command line tool %s could not be found" : "Não foi encontrada a ferramenta de linha de comando %s",
    "The library %s is not available." : "A biblioteca %s não está disponível.",
    "Library %s with a version higher than %s is required - available version %s." : "É necessário a biblioteca %s com uma versão superior a %s - versão disponível: %s.",
    "Library %s with a version lower than %s is required - available version %s." : "É necessário a biblioteca %s com uma versão inferior a %s - versão disponível: %s.",
    "Following platforms are supported: %s" : "São suportadas as seguintes plataformas: %s",
    "ownCloud %s or higher is required." : "É necessário o ownCloud %s ou superior.",
    "ownCloud %s or lower is required." : "É necessário o ownCloud %s ou inferior.",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "Invalid image" : "Imagem inválida",
    "Avatar image is not square" : "A imagem do avatar não é quadrada",
    "today" : "hoje",
    "yesterday" : "ontem",
    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás"],
    "last month" : "ultimo mês",
    "last year" : "ano passado",
    "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás"],
    "_%n hour ago_::_%n hours ago_" : ["%n hora atrás","%n horas atrás"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minutos atrás","%n minutos atrás"],
    "seconds ago" : "segundos atrás",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "O módulo com o id: %s não existe. Por favor, ative-o nas definições da sua aplicação ou contacte o seu administrador.",
    "Builtin" : "Integrado",
    "None" : "Nenhum",
    "Username and password" : "Nome de utilizador e palavra-passe",
    "Username" : "Nome de utilizador",
    "Password" : "Palavra-passe",
    "Log-in credentials, save in session" : "Credenciais de sessão, guardar na sessão",
    "Empty filename is not allowed" : "Não é permitido um ficheiro sem nome",
    "Dot files are not allowed" : "Ficheiros dot não são permitidos",
    "4-byte characters are not supported in file names" : "Carateres de 4 bytes não são suportados nos nomes de ficheiro",
    "File name is a reserved word" : "Nome de ficheiro é uma palavra reservada",
    "File name contains at least one invalid character" : "Nome de ficheiro contém pelo menos um caráter inválido",
    "File name is too long" : "Nome do ficheiro demasiado longo",
    "App directory already exists" : "A diretoria da aplicação já existe",
    "Can't create app folder. Please fix permissions. %s" : "Não foi possível criar a pasta da aplicação. Por favor verifique as permissões. %s",
    "Archive does not contain a directory named %s" : "O arquivo não contém uma diretoria com o nome %s",
    "No source specified when installing app" : "Não foi especificada uma fonte quando instalava a aplicação",
    "No href specified when installing app from http" : "Não foi especificada uma href http para instalar esta aplicação",
    "No path specified when installing app from local file" : "Não foi especificado o caminho de instalação desta aplicação",
    "Archives of type %s are not supported" : "Arquivos do tipo %s não são suportados",
    "Failed to open archive when installing app" : "Falhou a abertura do ficheiro quando instalava a aplicação",
    "App does not provide an info.xml file" : "A aplicação não disponibiliza um ficheiro info.xml",
    "App cannot be installed because appinfo file cannot be read." : "A aplicação não pode ser instalada porque o ficheiro appinfo não pode ser lido.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Não foi possível verificar a assinatura. Por favor, contacte o programador da aplicação e verifique o ecrã de administrador.",
    "App can't be installed because of not allowed code in the App" : "A aplicação não pode ser instalado devido a código não permitido dentro da aplicação",
    "App can't be installed because it is not compatible with this version of ownCloud" : "A aplicação não pode ser instalada por não ser compatível com esta versão do ownCloud",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Esta aplicação não pode ser instalada por que contém o tag <shipped>true</shipped> que só é permitido para aplicações nativas",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Esta aplicação não pode ser instalada porque a versão no info.xml não coincide com a reportada na loja de aplicações",
    "Apps" : "Aplicações",
    "General" : "Geral",
    "Storage" : "Armazenamento",
    "Security" : "Segurança",
    "User Authentication" : "Autenticação de Utilizador",
    "Encryption" : "Encriptação",
    "Workflows & Tags" : "Fluxo de Trabalho & Identificadores",
    "Sharing" : "Partilha",
    "Search" : "Procurar",
    "Updates" : "Atualizações",
    "Help & Tips" : "Ajuda & Dicas",
    "Additional" : "Adicional",
    "%s enter the database username and name." : "%s introduza o nome de utilizador da base de dados e o nome da base de dados.",
    "%s enter the database username." : "%s introduza o nome de utilizador da base de dados",
    "%s enter the database name." : "%s introduza o nome da base de dados",
    "%s you may not use dots in the database name" : "%s não é permitido utilizar pontos (.) no nome da base de dados",
    "Oracle connection could not be established" : "Não foi possível estabelecer a ligação Oracle",
    "Oracle username and/or password not valid" : "Nome de utilizador/palavra-passe do Oracle inválida",
    "DB Error: \"%s\"" : "Erro na BD: \"%s\"",
    "Offending command was: \"%s\"" : "O comando gerador de erro foi: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Precisa de introduzir uma conta existente ou de administrador",
    "Offending command was: \"%s\", name: %s, password: %s" : "O comando gerador de erro foi: \"%s\", nome: %s, password: %s",
    "PostgreSQL username and/or password not valid" : "Nome de utilizador/palavra-passe do PostgreSQL inválida",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Esta plataforma não suporta o sistema operativo Mac OS X e o %s poderá não funcionar correctamente. Utilize por sua conta e risco.",
    "For the best results, please consider using a GNU/Linux server instead." : "Para um melhor resultado, utilize antes o servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que a instância %s está a ser executada num ambiente PHP de 32-bits e o open_basedir foi configurado no php.ini. Isto levará a problemas com ficheiros de tamanho superior a 4 GB e é altamente desencorajado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a definição open_basedir do seu php.ini ou altere o seu PHP para 64-bits.",
    "Set an admin username." : "Definir um nome de utilizador de administrador",
    "Set an admin password." : "Definir uma palavra-passe de administrador.",
    "Can't create or write into the data directory %s" : "Não é possível criar ou escrever na diretoria 'data' %s",
    "Invalid Federated Cloud ID" : "Id. de Nuvem Federada Inválida",
    "%s shared »%s« with you" : "%s partilhou »%s« consigo",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "A partilha de %s falhou porque a interface não permite as partilhas do tipo %i",
    "Sharing %s failed, because the file does not exist" : "A partilha de %s falhou, porque o ficheiro não existe",
    "You are not allowed to share %s" : "Não está autorizado a partilhar %s",
    "Sharing %s failed, because you can not share with yourself" : "A partilha de %s falhou, porque não é possível partilhar consigo mesmo",
    "Sharing %s failed, because the user %s does not exist" : "A partilha %s falhou, porque o utilizador %s nao existe",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "A partilha %s falhou, porque o utilizador %s não pertence a nenhum dos grupos que %s é membro de",
    "Sharing %s failed, because this item is already shared with %s" : "A partilha %s falhou, porque o item já está a ser partilhado com %s",
    "Sharing %s failed, because this item is already shared with user %s" : "A partilha de %s falhou, porque este item já está a ser partilhado com o utilizador %s",
    "Sharing %s failed, because the group %s does not exist" : "A partilha %s falhou, porque o grupo %s não existe",
    "Sharing %s failed, because %s is not a member of the group %s" : "A partilha %s falhou, porque o utilizador %s não é membro do grupo %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Precisa de fornecer a palavra-passe para criar uma hiperligação pública, só são permitidas hiperligações protegidas",
    "Sharing %s failed, because sharing with links is not allowed" : "A partilha de %s falhou, porque partilhar com links não é permitido",
    "Not allowed to create a federated share with the same user" : "Não é possível criar uma partilha federada com o mesmo utilizador",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "A partilha de %s falhou, não foi possível encontrar %s. É possível que o servidor esteja inacessível.",
    "Share type %s is not valid for %s" : "O tipo de partilha %s não é válido para %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Definir permissões para %s falhou, porque as permissões excedem as permissões concedidas a %s",
    "Setting permissions for %s failed, because the item was not found" : "Definir permissões para %s falhou, porque o item não foi encontrado",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Não é possível definir data de expiração. As partilhas não podem expirar mais de %s depois de terem sido partilhadas",
    "Cannot set expiration date. Expiration date is in the past" : "Não é possivel definir data de expiração. A data de expiração está no passado",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Não é possível limpar a data de expiração. As partilhas devem ter uma data de expiração.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Ao partilhar a interface %s deve implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Não foi encontrada a partilha da interface %s",
    "Sharing backend for %s not found" : "Não foi encontrada a partilha da interface para %s",
    "Sharing failed, because the user %s is the original sharer" : "A partilha falhou, porque o utilizador %s é o distribuidor original",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Definir permissões para %s falhou, porque as permissões excedem as permissões concedidas a %s",
    "Sharing %s failed, because resharing is not allowed" : "A partilha %s falhou, porque repartilhar não é permitido",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "A partilha %s falhou porque a partilha da interface para %s não conseguiu encontrar a sua fonte",
    "Sharing %s failed, because the file could not be found in the file cache" : "A partilha %s falhou, devido ao ficheiro não poder ser encontrado na cache de ficheiros",
    "Cannot increase permissions of %s" : "Não é possível aumentar as permissões de %s",
    "Files can't be shared with delete permissions" : "Ficheiros não podem ser partilhados com permissões de apagar",
    "Files can't be shared with create permissions" : "Ficheiros não podem ser partilhados com permissões de criação",
    "Expiration date is in the past" : "A data de expiração está no passado",
    "Cannot set expiration date more than %s days in the future" : "Não é possível definir data de expiração a mais de %s dias no futuro",
    "Could not find category \"%s\"" : "Não foi encontrado a categoria \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Apenas os seguintes caracteres são permitidos num nome de utilizador: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
    "A valid username must be provided" : "Um nome de utilizador válido deve ser fornecido",
    "Username contains whitespace at the beginning or at the end" : "Nome de utilizador contém espaço em branco no início ou no fim",
    "A valid password must be provided" : "Deve ser indicada uma palavra-passe válida",
    "The username is already being used" : "O nome de utilizador já está a ser utilizado",
    "Login canceled by app" : "Início de sessão cancelada pela aplicação",
    "User disabled" : "Utilizador desativado",
    "Help" : "Ajuda",
    "Settings" : "Definições",
    "Users" : "Utilizadores",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "A aplicação \"%s\" não pode ser instalada porque as seguintes dependências não podem ser realizadas: %s",
    "web services under your control" : "serviços da Web sob o seu controlo",
    "File is currently busy, please try again later" : "O ficheiro está ocupado, por favor, tente mais tarde",
    "Can't read file" : "Não é possível ler o ficheiro",
    "Application is not enabled" : "A aplicação não está ativada",
    "Authentication error" : "Erro de autenticação",
    "Token expired. Please reload page." : "O código expirou. Por favor, recarregue a página.",
    "Unknown user" : "Utilizador desconhecido",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Sem controladores da base de dados (mysql, postgresql ou sqlite) instalados.",
    "Cannot write into \"config\" directory" : "Não é possível escrever na directoria \"configurar\"",
    "Cannot write into \"apps\" directory" : "Não é possivel escrever na directoria \"aplicações\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Isto pode ser normalmente resolvido %sdando ao servidor web direito de escrita para o directório de aplicação%s ou desactivando a loja de aplicações no ficheiro de configuração.",
    "Cannot create \"data\" directory" : "Não é possível criar a diretoria de \"dados\"",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Isto pode normalmente ser resolvido <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dando ao servidor web direito de escrita para o directório do root</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "As autorizações podem ser resolvidas normalmente %sdando ao servidor web direito de escrita para o directório root%s.",
    "Setting locale to %s failed" : "Definindo local para %s falhado",
    "Please install one of these locales on your system and restart your webserver." : "Por favor instale um destes locais no seu sistema e reinicie o seu servidor web.",
    "Please ask your server administrator to install the module." : "Por favor pergunte ao seu administrador do servidor para instalar o modulo.",
    "PHP module %s not installed." : "O modulo %s PHP não está instalado.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Configuração PHP \"%s\" não está definida para \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Ajustar esta configuração no php.ini fará com que o ownCloud funcione de novo",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está configurado para \"%s\" invés do valor habitual de \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corrigir este problema altere o <code>mbstring.func_overload</code> para <code>0</code> no seu php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Necessária pelo menos libxml2 2.7.0. Atualmente %s está instalada.",
    "To fix this issue update your libxml2 version and restart your web server." : "Para corrigir este problema actualize a versão da libxml2 e reinicie o seu servidor web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado a remover blocos doc em linha. Isto vai tornar algumas aplicações básicas inacessíveis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto é provavelmente causado por uma cache/acelerador como o Zend OPcache or eAcelerador.",
    "PHP modules have been installed, but they are still listed as missing?" : "Os módulos PHP foram instalados,   mas eles ainda estão listados como desaparecidos?",
    "Please ask your server administrator to restart the web server." : "Pro favor pergunte ao seu administrador do servidor para reiniciar o servidor da internet.",
    "PostgreSQL >= 9 required" : "Requerido PostgreSQL >= 9",
    "Please upgrade your database version" : "Por favor, atualize a sua versão da base de dados",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor, altere as permissões para 0770, e assim essa diretoria não pode ser listada pelos outros utilizadores.",
    "Your Data directory is readable by other users" : "A sua diretoria 'Data' é legível pelos outros utilizadores",
    "Your Data directory must be an absolute path" : "A sua diretoria 'Data' deve ser um caminho absoluto",
    "Check the value of \"datadirectory\" in your configuration" : "Verifique o valor de \"datadirectory\" na sua configuração",
    "Your Data directory  is invalid" : "A sua diretoria 'Data' é inválida",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Por favor, verifique se a diretoria 'data' contém um ficheiro \".ocdata\" na sua raiz.",
    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter o tipo de bloqueio %d em \"%s\".",
    "Storage unauthorized. %s" : "Armazenamento desautorizado. %s",
    "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
    "Storage connection error. %s" : "Erro de ligação ao armazenamento. %s",
    "Storage is temporarily not available" : "O armazenamento está temporariamente indisponível",
    "Storage connection timeout. %s" : "Tempo de ligação ao armazenamento expirou. %s"
},
"nplurals=2; plural=(n != 1);");
